#ifndef PixmapList_h
#define PixmapList_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "TaskAttributes.h"
#include "TaskBarAttributes.h"

#include <QVector>
#include <QPixmap>

//* handles collection of pixmaps needed to draw a single button
class PixmapList: public Counter
{

    public:

    //* constructor
    PixmapList( void );

    //* constructor
    void setAttributes( const TaskBarAttributes&, const TaskAttributes& );

    //* get pixmap matching given size and highlight
    /**
    note: the method is set to 'const' although technically it has the ability
    to modify the internal cache.
    */
    QPixmap get( int, int ) const;

    //* max size index
    int maxSizeIndex( void ) const
    { return maxSizeIndex_; }

    //* max highlight index
    int maxHighlightIndex( void ) const
    { return maxHighlightIndex_; }

    protected:

    //* returns unique index from size and highlight
    int _index( int sizeIndex, int highlightIndex ) const;

    private:

    //* taskBar attributes
    TaskBarAttributes taskBarAttributes_;

    //* task attributes
    TaskAttributes attributes_;

    //* max size
    int maxSize_ = 0;

    //* min size
    int minSize_ = 0;

    //* size increment
    int sizeIncrement_ = 0;

    //* max size index
    int maxSizeIndex_ = 0;

    //* max highlight index
    int maxHighlightIndex_ = 0;

    //* full intensity
    double fullIntensity_ = 0;

    //* pixmap list
    using List = QVector<QPixmap>;

    //* normal pixmap
    List pixmaps_;

};

#endif
