#ifndef TaskBarConfiguration_h
#define TaskBarConfiguration_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "CustomDialog.h"
#include "TimeStamp.h"
#include "TaskBarAttributes.h"

#include <QCheckBox>
#include <QComboBox>
#include <QSpinBox>
#include <QWidget>
#include <QHash>

class LineEditor;
class CustomSlider;

//* task information editor dialog
class TaskBarConfiguration: public QWidget, public Counter
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    TaskBarConfiguration(
    QWidget* parent,
    const TaskBarAttributes& attributes = TaskBarAttributes()
    );

    //* attributes
    void setAttributes( const TaskBarAttributes& attributes );

    //* retrieve backup attributes
    const TaskBarAttributes& backupAttributes( void )
    { return backupAttributes_; }

    //* retrieve attributes
    const TaskBarAttributes& attributes( void );

    Q_SIGNALS:

    //* emitted when the pressed button is called
    void configurationChanged( const TaskBarAttributes& attributes );

    public Q_SLOTS:

    //* apply changes, emit config changed
    void apply( void )
    { emit configurationChanged( attributes() ); }

    //* reset
    void cancel( void )
    { emit configurationChanged( backupAttributes() ); }

    private Q_SLOTS:

    //* toggle button position
    void _togglePosition( QAbstractButton* );

    //* enable/disable columnSpinBox_ according to the layout
    void _updateLayout( const QString& value );

    //* enable/disable options according to the layout mode
    void _updateMode( const QString& value );

    //* update cheboxes depending on what is checked or not
    void _updateCheckBoxes( void );

    protected:

    //* create position box
    QWidget* _positionBox( QWidget *parent );

    //* check options
    void _check( void );

    private:

    //* map buttons to position
    using ButtonMap = QHash< QAbstractButton*, TaskBarAttributes::PositionMode >;

    //* position buttons
    ButtonMap positionButtons_;

    //* attributes backup
    TaskBarAttributes backupAttributes_;

    //* associated TaskAttributes
    TaskBarAttributes attributes_;

    //* name editor
    LineEditor* nameLineEdit_;

    //* layout combobox
    QComboBox* layoutComboBox_;

    //* mode combobox
    QComboBox* modeComboBox_;

    //* zoom delay spinbox
    QSpinBox* delaySpinBox_;

    //* n columns spinbox
    QSpinBox* columnSpinBox_;

    //* scale spinbox
    QSpinBox* scaleSpinBox_;

    //* checkboxes
    using CheckBoxMap = QHash< TaskBarAttributes::Flag, QCheckBox* >;

    //* checkbox map
    CheckBoxMap checkboxes_;

};

#endif
