#ifndef TaskListConfiguration_h
#define TaskListConfiguration_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "TaskAttributesModel.h"
#include "TreeView.h"

#include <QWidget>
#include <QPushButton>

//! task information editor dialog
class TaskListConfiguration: public QWidget, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    TaskListConfiguration(
        QWidget* parent,
        const TaskAttributes::List& taskList = TaskAttributes::List() );

    //! task list
    void setTaskList( const TaskAttributes::List& taskList );

    //! task list
    TaskAttributes::List taskAttributesList( void );

    //! backup task list
    const TaskAttributes::List& backupTaskAttributesList( void )
    { return backupTaskList_; }

    Q_SIGNALS:

    //! emitted when the pressed button is called
    void configurationChanged( const TaskAttributes::List& attributes );

    public Q_SLOTS:

    //! apply changes, emit config changed
    void apply( void );

    //! reset
    void cancel( void );

    protected Q_SLOTS:

    //! update buttons
    void _updateButtons( void );

    //! add a task
    void _add( void );

    //! add a separator
    void _addSeparator( void );

    //! edit selected task(s)
    void _edit( void );

    //! remove selected task
    void _remove( void );

    //! move up selected task
    void _up( void );

    //! move down selected task
    void _down( void );

    //! update buttons based on selection
    // void _updateButtons( void );

    private:

    //! attributes backup
    TaskAttributes::List backupTaskList_;

    //! model
    TaskAttributesModel model_;

    //! list of files
    TreeView* list_;

    //! add button
    QPushButton* addButton_;

    //! add separator
    QPushButton* addSeparator_;

    //! edit
    QPushButton* edit_;

    //! remove
    QPushButton* remove_;

    //! move up
    QPushButton* moveUp_;

    //! move down
    QPushButton* moveDown_;

};

#endif
